@@ -1,8 +1,9 @@
 # -*- coding: UTF-8 -*-
 import struct
 import ctypes
+import sys
 from ctypes import *
-from algorithmLib.Function import project_root_path
+
 
 class p563Struct(Structure):
  _fields_ = [
@@ -22,7 +23,7 @@ def cal_563_mos(degFile):
     :return: 无参考的MOS,语音电平，信噪比，噪声电平
     """
     p563 = p563Struct()
-    mydll = ctypes.windll.LoadLibrary(project_root_path() + 'algorithmLib/P563/p563.dll')
+    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/p563.dll')
     #buf = create_string_buffer(degFile.encode('gbk'), len(degFile))
     buf = c_char_p(bytes(degFile.encode('utf-8')))
     mydll.NR_MOS(buf,byref(p563))
